@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Mesh_3/include/CGAL/refine_mesh_3.h $
-// $Id: refine_mesh_3.h 62a8391 %aI Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14.1/Mesh_3/include/CGAL/refine_mesh_3.h $
+// $Id: refine_mesh_3.h 8648a72 %aI Laurent Rineau
 // SPDX-License-Identifier: GPL-3.0+
 //
 //
@@ -209,7 +209,10 @@ struct Mesh_3_options {
 #else
       typedef bool* Pointer_to_stop_atomic_boolean_t;
 #endif
-  Mesh_3_options()
+  Mesh_3_options(bool nonlinear = false)
+    // This parameter `nonlinear` adds a compatibility with previous
+    // API of the constructor of `C3t3_initializer`.
+    // -- Laurent Rineau, 2019/05/03
     : dump_after_init_prefix()
     , dump_after_refine_surface_prefix()
     , dump_after_refine_prefix()
@@ -217,7 +220,7 @@ struct Mesh_3_options {
     , dump_after_perturb_prefix()
     , dump_after_exude_prefix()
     , number_of_initial_points(-1)
-    , nonlinear_growth_of_balls(false)
+    , nonlinear_growth_of_balls(nonlinear)
     , maximal_number_of_vertices(0)
     , pointer_to_error_code(0)
 #ifndef CGAL_NO_ATOMIC
@@ -381,6 +384,7 @@ BOOST_PARAMETER_FUNCTION((internal::Mesh_3_options), mesh_3_options, tag,
                           (dump_after_exude_prefix_, (std::string), "" )
                           (number_of_initial_points_, (int), -1)
 			  (maximal_number_of_vertices_, (std::size_t), 0)
+                          (nonlinear_growth_of_balls_, (bool), false)
 			  (pointer_to_error_code_, (Mesh_error_code*), ((Mesh_error_code*)0))
 			  (pointer_to_stop_atomic_boolean_, (internal::Mesh_3_options::Pointer_to_stop_atomic_boolean_t), ((internal::Mesh_3_options::Pointer_to_stop_atomic_boolean_t)0))
                           )
@@ -395,6 +399,7 @@ BOOST_PARAMETER_FUNCTION((internal::Mesh_3_options), mesh_3_options, tag,
   options.dump_after_perturb_prefix=dump_after_perturb_prefix_;
   options.dump_after_exude_prefix=dump_after_exude_prefix_;
   options.number_of_initial_points=number_of_initial_points_;
+  options.nonlinear_growth_of_balls = nonlinear_growth_of_balls_;
   options.maximal_number_of_vertices=maximal_number_of_vertices_;
   options.pointer_to_error_code=pointer_to_error_code_;
 #ifndef CGAL_NO_ATOMIC
